package com.mysql.jdbc.jdbc2.optional;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;
import java.sql.SQLException;
import java.util.Map;

/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: com_mysql_jdbc_jdbc2_optional.jar:com/mysql/jdbc/jdbc2/optional/WrapperBase.class */
public abstract class WrapperBase {
    protected MysqlPooledConnection pooledConnection;
    protected Map unwrappedInterfaces = null;

    /* JADX INFO: Access modifiers changed from: protected */
    public void checkAndFireConnectionError(SQLException sqlEx) throws SQLException {
        if (this.pooledConnection != null && "08S01".equals(sqlEx.getSQLState())) {
            this.pooledConnection.callListener(1, sqlEx);
        }
        throw sqlEx;
    }

    /* loaded from: com_mysql_jdbc_jdbc2_optional.jar:com/mysql/jdbc/jdbc2/optional/WrapperBase$ConnectionErrorFiringInvocationHandler.class */
    protected class ConnectionErrorFiringInvocationHandler implements InvocationHandler {
        Object invokeOn;
        private final WrapperBase this$0;

        public ConnectionErrorFiringInvocationHandler(WrapperBase this$0, Object toInvokeOn) {
            this.this$0 = this$0;
            this.invokeOn = null;
            this.invokeOn = toInvokeOn;
        }

        @Override // java.lang.reflect.InvocationHandler
        public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
            Object result = null;
            try {
                result = method.invoke(this.invokeOn, args);
                if (result != null) {
                    result = proxyIfInterfaceIsJdbc(result, result.getClass());
                }
            } catch (InvocationTargetException e) {
                if (e.getTargetException() instanceof SQLException) {
                    this.this$0.checkAndFireConnectionError((SQLException) e.getTargetException());
                } else {
                    throw e;
                }
            }
            return result;
        }

        private Object proxyIfInterfaceIsJdbc(Object toProxy, Class clazz) {
            Class[] interfaces = clazz.getInterfaces();
            if (0 < interfaces.length) {
                String packageName = interfaces[0].getPackage().getName();
                if ("java.sql".equals(packageName) || "javax.sql".equals(packageName)) {
                    return Proxy.newProxyInstance(toProxy.getClass().getClassLoader(), interfaces, new ConnectionErrorFiringInvocationHandler(this.this$0, toProxy));
                }
                return proxyIfInterfaceIsJdbc(toProxy, interfaces[0]);
            }
            return toProxy;
        }
    }
}
